==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/sq/base.php <==
<?php

return [
    'Logging' => 'Logging',
    'Spaces' => 'Hapësirat',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module </strong> administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'About' => '',
    'Admin' => '',
    'Administration' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Approval' => '',
    'Authentication' => '',
    'Back to overview' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Basic' => '',
    'Caching' => '',
    'Cronjobs' => '',
    'Default' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Design' => '',
    'Files' => '',
    'General' => '',
    'Groups' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logs' => '',
    'Mailing' => '',
    'Modules' => '',
    'Notifications' => '',
    'OEmbed' => '',
    'OEmbed providers' => '',
    'Open documentation' => '',
    'Pending user registrations' => '',
    'People' => '',
    'Permissions' => '',
    'Proxy' => '',
    'Self test' => '',
    'Settings' => '',
    'Sign up' => '',
    'Statistics' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'User posts' => '',
    'Userprofiles' => '',
    'Users' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/sq/base.php <==
<?php

return [
    'Invalid user state: {state}' => 'Shtet invalit i përdoruesit: {state}',
    'Logging' => 'Logging',
    'Spaces' => 'Hapësirat',
    'User not found!' => 'Përdoruesi nuk u gjind!',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module</strong> Administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'About' => '',
    'Activate' => '',
    'Add Licence Key' => '',
    'Admin' => '',
    'Administration' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Approval' => '',
    'Authentication' => '',
    'Back to overview' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Basic' => '',
    'Caching' => '',
    'Configure' => '',
    'Cronjobs' => '',
    'Deactivate' => '',
    'Default' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Design' => '',
    'Files' => '',
    'General' => '',
    'Groups' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logs' => '',
    'Mailing' => '',
    'Modules' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'Notifications' => '',
    'OEmbed' => '',
    'OEmbed providers' => '',
    'Open documentation' => '',
    'Pending user registrations' => '',
    'People' => '',
    'Permissions' => '',
    'Proxy' => '',
    'Search' => '',
    'Search...' => '',
    'Self test' => '',
    'Set as default' => '',
    'Settings' => '',
    'Sign up' => '',
    'Statistics' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'Uninstall' => '',
    'Userprofiles' => '',
    'Users' => '',
];
